# Package:  mio
# Date:     15th April 2012
# Author:   James Mills, prologic at shortcircuit dot net dot au

"""A Toy Programming Language written in Python

mio is a Toy Programming Language written in the `Python Programming Language`_.

:copyright: CopyRight (C) 2012-2013 by James Mills

.. _Python Programming Language: http://www.python.org/
"""

__author__ = "James Mills"
__date__ = "23rd October 2012"

from .version import version as __version__
